@@ -14,3 +14,6 @@ class StytchError(Exception):
 
     def __repr__(self):
         return "StytchError {0}".format(self.__dict__)
+
+    def __str__(self):
+        return str(self.__dict__)
