@@ -1,4 +1,4 @@
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 from .base import Base
 
@@ -16,11 +16,12 @@ class Users(Base):
 
     def create(
         self,
-        email: str,
+        email: str = None,
         phone_number: str = None,
         first_name: str = None,
         last_name: str = None,
         middle_name: str = None,
+        create_user_as_pending: Optional[bool] = False,
         attributes: Dict[str, str] = {},
     ):
         data = {
@@ -31,15 +32,16 @@ class Users(Base):
                 "middle_name": middle_name,
                 "last_name": last_name,
             },
+            "create_user_as_pending": create_user_as_pending,
         }
         if attributes and self._validate_attributes(attributes):
-            data.update(attributes)
+            data.update({"attributes": attributes})
         return self._post("{0}".format(self.user_url), data)
 
     def get(self, user_id: str):
         return self._get("{0}/{1}".format(self.user_url, user_id))
 
-    def get_pending_users(
+    def get_pending(
         self,
         limit: Optional[int] = None,
         starting_after_id: Optional[str] = None
@@ -58,8 +60,8 @@ class Users(Base):
     def update(
         self,
         user_id: str,
-        emails: Optional[list[str]] = None,
-        phone_numbers: Optional[list[str]] = None,
+        emails: Optional[List[str]] = None,
+        phone_numbers: Optional[List[str]] = None,
         first_name: Optional[str] = None,
         middle_name: Optional[str] = None,
         last_name: Optional[str] = None,
