@@ -30,10 +30,3 @@ class TestStytchClient:
         assert client.MagicLinks.send
         assert client.MagicLinks.send_by_email
         assert client.MagicLinks.authenticate
-
-    def test_Emails_controller_exists(self):
-        client = Client("project_id", "secret", "development", suppress_warnings=True)
-        assert client.Emails
-        assert client.Emails.verify_email
-        assert client.Emails.send_email_verification
-        assert client.Emails.delete_email
